#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from django.utils.translation import gettext_lazy as _

import horizon


class GroupTypes(horizon.Panel):
    name = _("Group Types")
    slug = 'group_types'
    permissions = (
        ('openstack.services.block-storage',
         'openstack.services.block-store',
         'openstack.services.volume',
         'openstack.services.volumev3'),
    )
    policy_rules = (("volume", "group:group_types_manage"),)
